@@ -5,7 +5,7 @@ def main():
     parser = argparse.ArgumentParser(prog ='pyinf', description ='easy file inserting') 
 
     #parser.add_argument('mode',help='(pypi) for pypi package setup', required = False)
-    parser.add_argument('mode', action='store', type=str, required=False)
+    parser.add_argument('mode', action='store', type=str)
 
     args = parser.parse_args()
 
